@@ -42,6 +42,9 @@ pub enum BackgroundCommand {
     /// Deletes the given file.
     Delete(String),
 
+    /// Forcefully triggers all loaders of a given file.
+    ForceReload(String),
+
     /// Executes the given loader after the given file has changed.
     ExecuteLoaderForChange(LoaderInfo),
 
@@ -118,6 +121,10 @@ pub fn actor(
                             Err(e) => log::error!("Failed to store data for: {} - {:?}", path, e),
                         }
                     }
+                    BackgroundCommand::ForceReload(path) => {
+                        log::info!("Forcing a reload of {}...", path);
+                        force_reload_command(&path, &files, &mut change_notifier).await;
+                    }
                     BackgroundCommand::Delete(path) => {
                         log::info!("Deleting {}...", path);
                         match delete_file_command(&path).await {
@@ -334,6 +341,29 @@ async fn sync_lists(
     previous_files: &[RepositoryFile],
     change_notifier: &mut mpsc::Sender<BackgroundEvent>,
 ) {
+    for old_file in previous_files {
+        if current_files
+            .iter()
+            .find(|other| &old_file == other)
+            .is_none()
+        {
+            log::info!("Deleted file found in repository: {}", old_file.name);
+
+            if let Err(error) = change_notifier
+                .send(BackgroundEvent::FileEvent(FileEvent::FileDeleted(
+                    old_file.clone(),
+                )))
+                .await
+            {
+                log::error!(
+                    "Failed to notify frontend about the deletion of {}: {}",
+                    old_file.name,
+                    error
+                );
+            }
+        }
+    }
+
     for new_file in current_files {
         if previous_files
             .iter()
@@ -358,29 +388,6 @@ async fn sync_lists(
             }
         }
     }
-
-    for old_file in previous_files {
-        if current_files
-            .iter()
-            .find(|other| &old_file == other)
-            .is_none()
-        {
-            log::info!("Deleted file found in repository: {}", old_file.name);
-
-            if let Err(error) = change_notifier
-                .send(BackgroundEvent::FileEvent(FileEvent::FileDeleted(
-                    old_file.clone(),
-                )))
-                .await
-            {
-                log::error!(
-                    "Failed to notify frontend about a the delete of {}: {}",
-                    old_file.name,
-                    error
-                );
-            }
-        }
-    }
 }
 
 async fn store_file_command(path: &str, data: Vec<u8>) -> anyhow::Result<()> {
@@ -416,6 +423,25 @@ async fn delete_file_command(path: &str) -> anyhow::Result<()> {
     Ok(())
 }
 
+async fn force_reload_command(
+    path: &str,
+    files: &[RepositoryFile],
+    change_notifier: &mut mpsc::Sender<BackgroundEvent>,
+) {
+    for file in files {
+        if file.name.contains(path) {
+            if let Err(error) = change_notifier
+                .send(BackgroundEvent::FileEvent(FileEvent::FileChanged(
+                    file.clone(),
+                )))
+                .await
+            {
+                log::error!("Failed to forcefully reload {}: {}", file.name, error);
+            }
+        }
+    }
+}
+
 async fn fetch_file_command(path: &str, url: &str, force: bool) -> anyhow::Result<()> {
     use tokio::io::AsyncWriteExt;
 
